
https://user-images.githubusercontent.com/90014847/235641562-67a09617-c1b6-4438-a38c-d1533326a43c.mp4


ima
===

Image searcher and downloader

- [Introduction](https://github.com/tcheukueppo/ima#Introduction)
- [Installation](https://github.com/tcheukueppo/ima#Installation)
- [Documentation](https://github.com/tcheukueppo/ima#Documentation)
- [License](https://github.com/tcheukueppo/ima#License)
- [Authors](https://github.com/tcheukueppo/ima#Authors)

ima is an extremely tiny python library command line utility which permits you to query search engines(e.g DuckDuckGo)
and download images from web pages.

ima might be a utility of choice for the following purpose:

- Downloading images from the internet to build up your dataset
- Searching on the internet with Google, DuckDuckGo or Yahoo. You would want to
  use multiple search engines to obtain better results.
- Caching your search results to later on use them locally.

# Installation

```{python}
pip install ima-search
```

# Documentation

Read the documentation from [here](./docs/introduction.md)

# License

ima is licensed under GPLv3

# Authors

Kueppo Tcheukam, tcheukueppo@tutanota.com
